@@ -12,7 +12,7 @@ Usage::
     client: STSClient = boto3.client("sts")
     ```
 """
-from typing import Any, Dict, List, Type
+from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -35,7 +35,7 @@ __all__ = ("STSClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -54,7 +54,7 @@ class Exceptions:
 
 class STSClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/sts.html#STS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sts.html#STS.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html)
     """
 
@@ -71,11 +71,11 @@ class STSClient(BaseClient):
         *,
         RoleArn: str,
         RoleSessionName: str,
-        PolicyArns: List["PolicyDescriptorTypeTypeDef"] = None,
+        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = None,
         Policy: str = None,
         DurationSeconds: int = None,
-        Tags: List["TagTypeDef"] = None,
-        TransitiveTagKeys: List[str] = None,
+        Tags: Sequence["TagTypeDef"] = None,
+        TransitiveTagKeys: Sequence[str] = None,
         ExternalId: str = None,
         SerialNumber: str = None,
         TokenCode: str = None,
@@ -85,7 +85,7 @@ class STSClient(BaseClient):
         Returns a set of temporary security credentials that you can use to access
         Amazon Web Services resources that you might not normally have access to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/sts.html#STS.Client.assume_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sts.html#STS.Client.assume_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role)
         """
 
@@ -95,7 +95,7 @@ class STSClient(BaseClient):
         RoleArn: str,
         PrincipalArn: str,
         SAMLAssertion: str,
-        PolicyArns: List["PolicyDescriptorTypeTypeDef"] = None,
+        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = None,
         Policy: str = None,
         DurationSeconds: int = None
     ) -> AssumeRoleWithSAMLResponseTypeDef:
@@ -103,7 +103,7 @@ class STSClient(BaseClient):
         Returns a set of temporary security credentials for users who have been
         authenticated via a SAML authentication response.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/sts.html#STS.Client.assume_role_with_saml)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sts.html#STS.Client.assume_role_with_saml)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role_with_saml)
         """
 
@@ -114,7 +114,7 @@ class STSClient(BaseClient):
         RoleSessionName: str,
         WebIdentityToken: str,
         ProviderId: str = None,
-        PolicyArns: List["PolicyDescriptorTypeTypeDef"] = None,
+        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = None,
         Policy: str = None,
         DurationSeconds: int = None
     ) -> AssumeRoleWithWebIdentityResponseTypeDef:
@@ -122,7 +122,7 @@ class STSClient(BaseClient):
         Returns a set of temporary security credentials for users who have been
         authenticated in a mobile or web application with a web identity provider.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role_with_web_identity)
         """
 
@@ -130,7 +130,7 @@ class STSClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/sts.html#STS.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sts.html#STS.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#can_paginate)
         """
 
@@ -141,21 +141,21 @@ class STSClient(BaseClient):
         Decodes additional information about the authorization status of a request from
         an encoded message returned in response to an Amazon Web Services request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/sts.html#STS.Client.decode_authorization_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sts.html#STS.Client.decode_authorization_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#decode_authorization_message)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/sts.html#STS.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sts.html#STS.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#generate_presigned_url)
         """
 
@@ -163,7 +163,7 @@ class STSClient(BaseClient):
         """
         Returns the account identifier for the specified access key ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/sts.html#STS.Client.get_access_key_info)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sts.html#STS.Client.get_access_key_info)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_access_key_info)
         """
 
@@ -172,7 +172,7 @@ class STSClient(BaseClient):
         Returns details about the IAM user or role whose credentials are used to call
         the operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/sts.html#STS.Client.get_caller_identity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sts.html#STS.Client.get_caller_identity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_caller_identity)
         """
 
@@ -181,15 +181,15 @@ class STSClient(BaseClient):
         *,
         Name: str,
         Policy: str = None,
-        PolicyArns: List["PolicyDescriptorTypeTypeDef"] = None,
+        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = None,
         DurationSeconds: int = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> GetFederationTokenResponseTypeDef:
         """
         Returns a set of temporary security credentials (consisting of an access key ID,
         a secret access key, and a security token) for a federated user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/sts.html#STS.Client.get_federation_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sts.html#STS.Client.get_federation_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_federation_token)
         """
 
@@ -200,6 +200,6 @@ class STSClient(BaseClient):
         Returns a set of temporary credentials for an Amazon Web Services account or IAM
         user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/sts.html#STS.Client.get_session_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sts.html#STS.Client.get_session_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_session_token)
         """
